@@ -1,8 +1,9 @@
+import re, itertools
 from collections.abc import Sequence
-import re, itertools, inspect, logging
-from .. import utils
 from copy import deepcopy
 
+from .. import utils
+
 
 # various regexp objects used in the module
 _re_name_id = re.compile(r"\s*([a-zA-Z0-9_]+)(?:\s*@\s*([a-zA-Z0-9_]+))?\s*(=)?")
